@@ -19,7 +19,7 @@
 
 from gettext import gettext as _
 
-from dob_bright.config.fileboss import default_config_path
+from dob_bright.config.fileboss import default_config_path, default_config_path_abbrev
 from dob_bright.config.urable import ConfigUrable
 from dob_bright.termio import attr, bg, coloring, fg, highlight_value
 
@@ -84,8 +84,8 @@ def _command_create_force_help(what):
     return _(
         """
         If specified, overwrite {} if is exists.
-        """.format(what)
-    )
+        """
+    ).format(what)
 
 
 # ***
@@ -96,8 +96,9 @@ def RUN_HELP_WHATIS():
     _help = _(
         """
         {appname} is a time tracker for the command line.
-        """.strip().format(**common_format())
-    )
+        """
+        .strip()
+    ).format(**common_format())
     return _help
 
 
@@ -107,8 +108,23 @@ def RUN_HELP_TRYME():
         - Try the demo to get acquainted with dob quickly,
 
           {codehi}{rawname} demo{reset}
-        """.strip().format(**common_format())
-    )
+        """
+        .strip()
+    ).format(**common_format())
+    return _help
+
+
+def RUN_HELP_QUICKIE():
+    _help = _(
+        """
+        - To start dobbin immediately, init, then edit,
+
+          {codehi}{rawname} init{reset}
+
+          {codehi}{rawname} edit{reset}
+        """
+        .strip()
+    ).format(**common_format())
     return _help
 
 
@@ -118,11 +134,15 @@ def RUN_HELP_HEADER():
         {what_is}
 
         {try_me}
-        """.strip().format(
-            what_is=RUN_HELP_WHATIS(),
-            try_me=RUN_HELP_TRYME(),
-            **common_format()
-        )
+
+        {quick_start}
+        """
+        .strip()
+    ).format(
+        what_is=RUN_HELP_WHATIS(),
+        try_me=RUN_HELP_TRYME(),
+        quick_start=RUN_HELP_QUICKIE(),
+        **common_format()
     )
     return _help
 
@@ -144,12 +164,13 @@ def RUN_HELP_TLDR():
 
         \b
         {copyright}
-        """.strip().format(
-            what_is=RUN_HELP_WHATIS(),
-            try_me=RUN_HELP_TRYME(),
-            copyright='\b\n        '.join(assemble_copyright()),
-            **common_format()
-        )
+        """
+        .strip()
+    ).format(
+        what_is=RUN_HELP_WHATIS(),
+        try_me=RUN_HELP_TRYME(),
+        copyright='\b\n        '.join(assemble_copyright()),
+        **common_format()
     )
     return _help
 
@@ -173,20 +194,20 @@ def RUN_HELP_COMPLETE():
 
         - Some commands have aliases, shown in (parentheses) below, e.g.,
 
-          {codehi}{rawname} details{reset} {equalityop} {codehi}{rawname} info{reset}
+          {codehi}{rawname} details{reset} {italic}is the same as{reset} {codehi}{rawname} info{reset}
 
         - For code rights and legal info, review the {copyrt_sym} and {scroll_sym},
 
           {codehi}{rawname} copyright{reset}
 
           {codehi}{rawname} license{reset}
-        """.strip().format(
-            run_help_header=RUN_HELP_HEADER(),
-            equalityop=coloring() and '≡' or '==',
-            copyrt_sym=coloring() and '©' or 'copyright',
-            scroll_sym=coloring() and '📜' or 'license',
-            **common_format()
-        )
+        """  # noqa: E501 line too long
+        .strip()
+    ).format(
+        run_help_header=RUN_HELP_HEADER(),
+        copyrt_sym=coloring() and '©' or 'copyright',
+        scroll_sym=coloring() and '📜' or 'license',
+        **common_format()
     )
     return _help
 
@@ -209,7 +230,7 @@ def RUN_HELP_OVERVIEW(ctx):
 
 HELP_HELP = _(
     """
-    Prints help for the application or for the specified command.
+    Print help for the application, or for the specified command.
     """
 )
 
@@ -220,7 +241,7 @@ HELP_HELP = _(
 
 VERSION_HELP = _(
     """
-    Prints the interface and library versions.
+    Print the interface and library versions.
     """
 )
 
@@ -231,7 +252,7 @@ VERSION_HELP = _(
 
 LICENSE_HELP = _(
     """
-    Prints the software license.
+    Print the software license.
     """
 )
 
@@ -242,7 +263,7 @@ LICENSE_HELP = _(
 
 COPYRIGHT_HELP = _(
     """
-    Prints the software copyright.
+    Print the software copyright.
     """
 )
 
@@ -260,7 +281,7 @@ ABOUT_COMMAND_HELP = _(
 
 DETAILS_HELP = _(
     """
-    Prints details about the runtime environment.
+    Print details about the runtime environment.
     """
 )
 
@@ -277,7 +298,7 @@ DETAILS_TMI_HELP = _(
 
 ENVIRONS_HELP = _(
     """
-    Prints shell-sourceable details about the runtime environment.
+    Print shell-sourceable details about the runtime environment.
 
     Useful for setting up shell scripting, e.g.,
 
@@ -318,9 +339,10 @@ DEBUG_HELP = _(
 def DEMO_HELP(ctx):
     _help = _(
         """
-        Teaches you how to {rawname} -- {italic}Run this first!{reset}
+        Learn {rawname} -- {italic}Run this first!{reset}
         """
-    ).strip().format(**common_format())
+        .strip()
+    ).format(**common_format())
     return _help
 
 
@@ -342,16 +364,16 @@ def INIT_HELP_OVERVIEW(ctx):
          {codehi}sqlite3 {cfg_db_path}{reset}
 
         But you'll probably just want to make sure you backup that file!
-            """.strip().format(
-                default_config_path=highlight_value(default_config_path()),
-                cfg_db_path=controller.config['db.path'],
-                **common_format()
-            )
+            """
+            .strip()
+        ).format(
+            cfg_db_path=controller.config['db.path'],
+            **common_format()
         )
 
     _help = _(
         """
-        Creates a default configuration file, and an empty database.
+        Create a default configuration file, and an empty database.
 
         - Unless it exists, init will create a default configuration at:
 
@@ -371,12 +393,13 @@ def INIT_HELP_OVERVIEW(ctx):
          {codehi}{rawname} config dump{reset}
 
         {_hint_sqlite}
-        """.strip().format(
-            default_config_path=highlight_value(default_config_path()),
-            hlg_db_path=highlight_value(controller.config['db.path']),
-            _hint_sqlite=_hint_sqlite,
-            **common_format()
-        )
+        """
+        .strip()
+    ).format(
+        default_config_path=highlight_value(default_config_path()),
+        hlg_db_path=highlight_value(controller.config['db.path']),
+        _hint_sqlite=_hint_sqlite,
+        **common_format()
     )
     return _help
 
@@ -388,7 +411,7 @@ def INIT_HELP_OVERVIEW(ctx):
 def CONFIG_GROUP_HELP(ctx):
     _help = _(
         """
-        Manages user config settings (including editor key bindings).
+        Manage user config settings (including editor key bindings).
 
         Some application behavior can be changed via config values.
 
@@ -419,11 +442,11 @@ def CONFIG_GROUP_HELP(ctx):
           {codehi}{rawname} COMMAND ...{reset}
 
         - You can alternatively specify the configuration file location
-        using the {codehi}-C/--configfile{reset} global option, e.g.,
+        using the {codehi}-F/--configfile{reset} global option, e.g.,
         using shorthand:
 
           \b
-          {codehi}{rawname} -C path/to/{rawname}.conf COMMAND ...{reset}
+          {codehi}{rawname} -F path/to/{rawname}.conf COMMAND ...{reset}
 
           or using --option=value longhand:
 
@@ -454,11 +477,11 @@ def CONFIG_GROUP_HELP(ctx):
         - If a config value is specified via the command line, that value is
         preferred over all other values.
 
-          - You can specify config values using the {codehi}-c/--config{reset}
+          - You can specify config values using the {codehi}-C/--config{reset}
         option, e.g.,
 
           \b
-          {codehi}{rawname} -c db.engine=sqlite stats{reset}
+          {codehi}{rawname} -C db.engine=sqlite stats{reset}
 
         {underlined}Config Command Overview{reset}
 
@@ -491,8 +514,7 @@ def CONFIG_GROUP_HELP(ctx):
           {codehi}{rawname} config show{reset}
 
           - If you think your config file is missing values, you can
-        update it with missing settings by running (naturally) the
-        update command:
+        update it with missing settings by running the update command:
 
           \b
           {codehi}{rawname} config update{reset}
@@ -503,18 +525,18 @@ def CONFIG_GROUP_HELP(ctx):
 
             - Although you might care about the config file contents if you'd
         like to add comments to it, which is supported.
-        """.format(
-            default_config_path=highlight_value(default_config_path()),
-            envkey=ConfigUrable.DOB_CONFIGFILE_ENVKEY,
-            **common_format()
-        )
+        """
+    ).format(
+        default_config_path=highlight_value(default_config_path()),
+        envkey=ConfigUrable.DOB_CONFIGFILE_ENVKEY,
+        **common_format()
     )
     return _help
 
 
 CONFIG_CREATE_HELP = _(
     """
-    Writes a new configuration file populated with default values.
+    Write a new configuration file populated with default values.
 
     You can overwrite an existing configuration file using --force.
     """
@@ -526,28 +548,28 @@ CONFIG_CREATE_FORCE_HELP = _command_create_force_help(_('config file'))
 
 CONFIG_EDIT_HELP = _(
     """
-    Opens the config file in your preferred $EDITOR.
+    Open the config file in your preferred $EDITOR.
     """
 )
 
 
 CONFIG_GET_HELP = _(
     """
-    Prints a configuration value from the config file.
+    Print a configuration value from the config file.
     """
 )
 
 
 CONFIG_SET_HELP = _(
     """
-    Writes a configuration value to the config file.
+    Write a configuration value to the config file.
     """
 )
 
 
 CONFIG_SHOW_HELP = _(
     """
-    Prints all config settings, including names, values, and help.
+    Print all config settings, including names, values, and help.
     """
 )
 
@@ -566,7 +588,7 @@ CONFIG_UPDATE_HELP = _(
 def STYLES_GROUP_HELP(ctx):
     _help = _(
         """
-        Manages editor styles (centering, dimensions, coloring, etc.).
+        Manage editor styles (centering, dimensions, coloring, and more).
 
         The easiest way to use styles is to choose one of the built-in
         styles and set it in your config.
@@ -679,16 +701,16 @@ def STYLES_GROUP_HELP(ctx):
         The value for each user-created style setting is a space-separated
         list of class name of style strings, as recognized by Python Prompt
         Toolkit and Pygments.
-        """.format(
-            **common_format()
-        )
+        """
+    ).format(
+        **common_format()
     )
     return _help
 
 
 STYLES_CREATE_HELP = _(
     """
-    Writes a new styles config file populated with basic styles options.
+    Write a new styles config file populated with basic styles options.
 
     You can overwrite an existing styles config file using --force.
     """
@@ -700,7 +722,7 @@ STYLES_CREATE_FORCE_HELP = _command_create_force_help(_('styles file'))
 
 STYLES_CONF_HELP = _(
     """
-    Prints the styles file, a section from it, or an internal style.
+    Print the styles file, a section from it, or an internal style.
 
     If no name is specified, prints the styles.conf file, in one exists.
     This includes any comments, too.
@@ -718,14 +740,14 @@ STYLES_CONF_HELP = _(
 
 STYLES_EDIT_HELP = _(
     """
-    Opens the styles config file in your preferred $EDITOR.
+    Open the styles config file in your preferred $EDITOR.
     """
 )
 
 
 STYLES_LIST_HELP = _(
     """
-    Displays a list of built-in and user-declared style names.
+    Display a list of built-in and user-declared style names.
 
     You can activate a style by assigning its value to `editor.styling`.
 
@@ -738,7 +760,7 @@ STYLES_LIST_HELP = _(
 
 STYLES_SHOW_HELP = _(
     """
-    Shows a table of basic style config settings and their descriptions.
+    View a table of basic style config settings and their descriptions.
     """
 )
 
@@ -750,22 +772,22 @@ STYLES_SHOW_HELP = _(
 def RULES_GROUP_HELP(ctx):
     _help = _(
         """
-        Manages style rules (to customize style for matching Facts).
+        Manage styles (customize matching Facts, activities, tags, etc.).
 
         See the styles help for detailed information:
 
           \b
           {codehi}{rawname} styles --help{reset}
-        """.format(
-            **common_format()
-        )
+        """
+    ).format(
+        **common_format()
     )
     return _help
 
 
 RULES_CREATE_HELP = _(
     """
-    Writes a new rules file populated with an example rule.
+    Write a new rules file populated with an example rule.
 
     You can overwrite an existing style rules file using --force.
     """
@@ -777,7 +799,7 @@ RULES_CREATE_FORCE_HELP = _command_create_force_help(_('style rules'))
 
 RULES_CONF_HELP = _(
     """
-    Prints the rules file, or a single rule if a rule name is supplied.
+    Print the rules file, or a single rule if a rule name is supplied.
 
     If no name is specified, prints the rules.conf file, in one exists.
     This includes any comments, too.
@@ -792,14 +814,14 @@ RULES_CONF_HELP = _(
 
 RULES_EDIT_HELP = _(
     """
-    Opens the rules file in your preferred $EDITOR.
+    Open the rules file in your preferred $EDITOR.
     """
 )
 
 
 RULES_LIST_HELP = _(
     """
-    Displays a list of user-defined rule names.
+    Display a list of user-defined rule names.
 
     Each rule is enabled by default.
 
@@ -816,7 +838,7 @@ RULES_LIST_HELP = _(
 
 RULES_SHOW_HELP = _(
     """
-    Shows rule settings in a table, including name, default value,
+    Show rule settings in a table, including name, default value,
     and description.
 
     If no name is supplied, an example ruleset is displayed.
@@ -835,16 +857,16 @@ def IGNORE_GROUP_HELP(ctx):
     _help = _(
         """
         Manages ignore lists (to exclude matching names from prompts).
-        """.format(
-            **common_format()
-        )
+        """
+    ).format(
+        **common_format()
     )
     return _help
 
 
 IGNORE_CREATE_HELP = _(
     """
-    Writes a new ignore file populated with example sections.
+    Write a new ignore file populated with example sections.
 
     You can overwrite an existing ignore file using --force.
     """
@@ -856,21 +878,21 @@ IGNORE_CREATE_FORCE_HELP = _command_create_force_help(_('ignore file'))
 
 IGNORE_EDIT_HELP = _(
     """
-    Opens the ignore file in your preferred $EDITOR.
+    Open the ignore file in your preferred $EDITOR.
     """
 )
 
 
 IGNORE_LIST_HELP = _(
     """
-    Displays the list of ignore file section names.
+    Display the list of ignore file section names.
     """
 )
 
 
 IGNORE_SHOW_HELP = _(
     """
-    Shows ignore rules in a table.
+    Show ignore rules in a table.
     """
 )
 
@@ -881,14 +903,14 @@ IGNORE_SHOW_HELP = _(
 
 STORE_GROUP_HELP = _(
     """
-    Manages the database file.
+    Manage the database: create a new one; upgrade from Hamster; and more.
     """
 )
 
 
 STORE_CREATE_HELP = _(
     """
-    Creates an empty database file.
+    Create an empty database file.
 
     You can overwrite an existing database file using --force.
     """
@@ -900,21 +922,21 @@ STORE_CREATE_FORCE_HELP = _command_create_force_help(_('data store'))
 
 STORE_PATH_HELP = _(
     """
-    Prints the database path.
+    Print the database path.
     """
 )
 
 
 STORE_URL_HELP = _(
     """
-    Prints the database URL.
+    Print the database URL.
     """
 )
 
 
 STORE_UPGRADE_LEGACY_HELP = _(
     """
-    Migrates a legacy “Hamster” database to dob.
+    Migrate a legacy “Hamster” database to dob.
     """
 )
 
@@ -930,9 +952,10 @@ STORE_UPGRADE_FORCE_HELP = _(
 # *** [STATS] Commands help.
 # ***
 
+# Print stats about your data (number of Facts, tags, etc.).
 STATS_HELP = _(
     """
-    Prints stats about your data store.
+    Print stats about your data (Fact count, tag count, etc.).
     """
 )
 
@@ -941,101 +964,175 @@ STATS_HELP = _(
 # *** [LIST] Commands help.
 # ***
 
-LIST_GROUP_HELP = _(
+QUERY_GROUP_HELP = _(
     """
-    Prints facts, activities, categories, or tags.
+    Print activity, category, or tag {item_part}.
     """
 )
 
 
-LIST_ACTIVITIES_HELP = _(
+QUERY_ITEM_HELP = _(
     """
-    Prints all activities. Provide optional filtering by name.
+    Print {item_type} {item_part}, optionally filtered and sorted.
 
-    Prints all matching activities one per line.
+    Finds all {item_types} by default, but results can be filtered by
+    Fact start and end times and name matches.
 
-    SEARCH: String to be matched against activity name.
+    Results are sorted by name by default, but can be sorted
+    by usage count, cumulative duration, or first Fact start
+    time.
+
+    Results are displayed in an ASCII table format by default,
+    available in many different styles, or can be converted to
+    comma-separated text (CSV), JSON, and other formats.
+
+    SEARCH_TERM: Use to match specific {item_type} name(s), ORed together.
     """
 )
 
 
-LIST_CATEGORIES_HELP = _(
+LIST_GROUP_HELP = QUERY_GROUP_HELP.format(item_part=_('names'))
+
+
+LIST_ACTIVITIES_HELP = QUERY_ITEM_HELP.format(
+    item_type=_("activity"),
+    item_types=_("activities"),
+    item_part=_('names'),
+)
+
+
+LIST_CATEGORIES_HELP = QUERY_ITEM_HELP.format(
+    item_type=_("category"),
+    item_types=_("categories"),
+    item_part=_('names'),
+)
+
+
+LIST_TAGS_HELP = QUERY_ITEM_HELP.format(
+    item_type=_("tag"),
+    item_types=_("tags"),
+    item_part=_('names'),
+)
+
+
+# (lb): The `list facts` command is hidden, but supported for parity.
+LIST_FACTS_HELP = QUERY_ITEM_HELP.format(
+    item_type=_("fact"),
+    item_types=_("facts"),
+    item_part=_('names'),
+)
+
+
+# ***
+# *** [FIND/SEARCH/JOURNAL/EXPORT] Commands help.
+# ***
+
+QUERY_HELP = _(
     """
-    Prints all existing categories, ordered by name.
+Add a SEARCH_TERM to find any Facts with a description that contains
+the specified search term. Or specify multiple terms to find any Fact
+that contains one or more terms.
+
+Use --broad to also loosely match the SEARCH_TERM against the activity,
+category, and tag values.
+
+Use --since and --until options to restrict the search to a specific
+time range.
+
+Use the --activity, --category, and --tags options to restrict the search
+to exact activity, category, and/or tag names.
+
+Use --order and --direction to specify how the results are sorted.
+
+Use --limit and --offset to fetch a portion of the results.
     """
 )
 
 
-LIST_TAGS_HELP = _(
+RESULTS_PROCESSING_HELP = _(
     """
-    Prints all tags.
+Prints to stdout, or use --output to send to a file.
+
+{query_help}
+
+Combine --group-activity and --group-category to group by Activity@Category
+names, or use them separately. You can also --group-tags. Or --group-days
+to group by whole days. Use any combination of groupings to change the
+results.
+
+Use one or more --column options to choose which details are output,
+and in what order.
+
+To choose a different output format, use --format <format>, or one of
+the format aliases (--journal, --json, etc.).
+
+Some formats and output columns have their options, too, listed last
+in the help.
     """
-)
-
-
-LIST_FACTS_HELP = _(
-    """
-    Prints facts within a date range.
-
-    Matching facts will be printed in a tabular representation.
-
-    TIME_RANGE: Only fact within this time range will be considered.
-    """
-)
+).format(query_help=QUERY_HELP)
 
 
 SEARCH_HELP = _(
     """
-    Finds facts matching a search term, time range and other options.
+Show all Facts, or those matching a search criteria.
 
-    You may use the SEARCH_TERM to find Facts with descriptions
-    that contain the SEARCH_TERM.
-
-    You may use the --since and --until options to restrict the
-    search to a specific time range.
-
-    You may use the --activity and --category options to restrict
-    the search to specific activity and category names.
+{results_processing_help}
     """
-)
+).format(results_processing_help=RESULTS_PROCESSING_HELP)
+
+
+def REPORT_HELP(ctx):
+    _help = _(
+        """
+Generate a report on recent time usage.
+
+This command is essentially an alias to:
+
+  \b
+  {codehi}{rawname} find --journal --since 'last week' \\{reset}
+  {codehi}   --group-activity --group-category --group-days \\{reset}
+  {codehi}   --sort usage --dir desc \\{reset}
+  {codehi}   -l start_date -l duration -l sparkline -l actegory -l tags_freq{reset}
+
+{results_processing_help}
+        """
+    ).format(results_processing_help=RESULTS_PROCESSING_HELP, **common_format())
+    return _help
 
 
 # ***
 # *** [USAGE] Commands help.
 # ***
 
-USAGE_GROUP_HELP = _(
-    """
-    Prints activity, category, or tag usage.
-    """
+USAGE_GROUP_HELP = QUERY_GROUP_HELP.format(item_part=_('usage'))
+
+
+USAGE_ACTIVITIES_HELP = QUERY_ITEM_HELP.format(
+    item_type=_("activity"),
+    item_types=_("activities"),
+    item_part=_('usage'),
 )
 
 
-USAGE_ACTIVITIES_HELP = _(
-    """
-    Prints all activities and their usage counts.
-    """
+USAGE_CATEGORIES_HELP = QUERY_ITEM_HELP.format(
+    item_type=_("category"),
+    item_types=_("categories"),
+    item_part=_('usage'),
 )
 
 
-USAGE_CATEGORIES_HELP = _(
-    """
-    Prints all categories and their usage counts.
-    """
+USAGE_TAGS_HELP = QUERY_ITEM_HELP.format(
+    item_type=_("tag"),
+    item_types=_("tags"),
+    item_part=_('usage'),
 )
 
 
-USAGE_TAGS_HELP = _(
-    """
-    Prints all tags by usage.
-    """
-)
-
-
-USAGE_FACTS_HELP = _(
-    """
-    Prints all facts by usage.
-    """
+# (lb): The `usage facts` command is hidden, but supported for parity.
+USAGE_FACTS_HELP = QUERY_ITEM_HELP.format(
+    item_type=_("fact"),
+    item_types=_("facts"),
+    item_part=_('usage'),
 )
 
 
@@ -1046,21 +1143,21 @@ USAGE_FACTS_HELP = _(
 STOP_HELP = _(
     # Not DRY: Copied from first line of ADD_FACT_THEN.
     """
-    Stops active Fact, ending it now or at the time specified.
+    Stop active Fact, ending it now or at the time specified.
     """
 )
 
 
 CANCEL_HELP = _(
     """
-    Discards the active Fact.
+    Discard the active Fact.
     """
 )
 
 
 CURRENT_HELP = _(
     """
-    Prints the active Fact, if there is one.
+    Print the active Fact, if there is one.
     """
 )
 
@@ -1070,20 +1167,21 @@ def NO_ACTIVE_FACT_HELP(ctx):
         """
         No active Fact. Try {italic}starting{reset} a new Fact first.
         """
-    ).strip().format(**common_format())
+        .strip()
+    ).format(**common_format())
     return _help
 
 
 LATEST_HELP = _(
     """
-    Prints latest completed Fact (Fact with most recent end time).
+    Print the latest completed Fact (with the most recent end time).
     """
 )
 
 
 HELP_CMD_SHOW = _(
     """
-    Prints the active Fact if exists, otherwise the latest Fact.
+    Print the active Fact, if any, otherwise the latest Fact.
     """
 )
 
@@ -1095,18 +1193,19 @@ HELP_CMD_SHOW = _(
 def ADD_FACT_REFERRAL():
     _help = _(
         """
-        For more help on this and the other Add Fact commands, try
+        For more help on this and the other add Fact commands, try
 
           {codehi}{rawname} --pager help add{reset}
-        """.strip().format(**common_format())
-    )
+        """
+        .strip()
+    ).format(**common_format())
     return _help
 
 
 # verify_none
 ADD_FACT_ON = _(
     """
-    Aliases the 'now' command, e.g., `dob on act@gory #tag: Blah...`.
+    Alias for 'now' command, e.g., `dob on act@gory #tag: Blah...`.
     """
 )
 
@@ -1115,7 +1214,7 @@ ADD_FACT_ON = _(
 ADD_FACT_NOW = _(
     # FIXME/2019-11-22: (lb): I think "if nothing active" might be wrong.
     """
-    Starts a new Fact if nothing active, using time now.
+    Start a new Fact only if no Fact is active, using time now.
     """
 )
 
@@ -1124,7 +1223,7 @@ ADD_FACT_NOW = _(
 ADD_FACT_START = _(
     # Not DRY: Copied from first line of ADD_FACT_AT.
     """
-    Starts new Fact, beginning now or at the time specified.
+    Start a new Fact, beginning now or at the time specified.
     """
 )
 
@@ -1134,15 +1233,15 @@ def ADD_FACT_AT(ctx):
     _help = _(
         """
         \b
-        Starts new Fact, beginning now or at the time specified.
+        Start a new Fact, beginning now or at the time specified.
 
         \b
-        This might stop the active fact, if one exists, and the time
-        specified comes after the active fact start time.
+        This might stop the active Fact, if one exists, and the time
+        specified comes after the active Fact start time.
 
         \b
-        Or this might change the start and/or stop time of other facts
-        if the fact being added overlaps other facts' time windows.
+        Or this might change the start and/or stop time of other Facts
+        if the Fact being added overlaps other Facts' time windows.
 
         {}
         """
@@ -1155,13 +1254,7 @@ def ADD_FACT_THEN(ctx):
     # FIXME/2019-11-22: Verify the 'just use a colon' text, I think that works.
     _help = _(
         """
-        Stops active Fact and Starts new, using now or time specified.
-
-        Ends active Fact and Starts new Fact, at now or offset.
-
-        Starts Fact, at time now or optional offset, ending active Fact.
-
-        Starts Fact, ending active Fact, using now or optional offset.
+        Stop the active Fact, and start a new one, at given time or now.
 
         This is basically a shortcut for the at command, which requires a time
         offset, e.g.,
@@ -1173,28 +1266,23 @@ def ADD_FACT_THEN(ctx):
           {rawname} at +0: Grinding beans...
 
         If you want to specify an offset, you can, just use a colon,
-        which could work well to throw down a gap fact, e.g.,
+        which could work well to throw down a gap Fact, e.g.,
 
           {rawname} then -5m: Woke up.
           {rawname} now Grinding beans...
-        """.strip().format(**common_format())
-    )
+        """
+        .strip()
+    ).format(**common_format())
     return _help
 
 
 # verify_still
 ADD_FACT_STILL = _(
     """
-    Stops active Fact and Starts new Fact, copying metadata.
+    Stop the active Fact, and start a new one, copying metadata.
 
-    Starts Fact, copying metadata from ending Fact.
-
-    Starts Fact, copying activity, category, and tags from ending Fact.
-
-    Ends active Fact, and starts new Fact, and copies forward metadata.
-
-    Starts the new Fact using the same Act@Gory and Tags (Metadata) as the
-    active Fact that is ended.
+    The new Fact is started with the same activity, category, and tags
+    as the Fact that is ended.
     """
 )
 
@@ -1204,18 +1292,19 @@ ADD_FACT_STILL = _(
 def ADD_FACT_AFTER(ctx):
     _help = _(
         """
-        Starts new Fact, beginning when the last Fact ended.
+        Start a new Fact, beginning when the last Fact ended.
 
         {}
-        """.strip().format(ADD_FACT_REFERRAL())
-    )
+        """
+        .strip()
+    ).format(ADD_FACT_REFERRAL())
     return _help
 
 
 # verify_after
 ADD_FACT_NEXT = _(
     """
-    Aliases the 'after' command, e.g., `dob next: Foo bar...`.
+    Alias for the 'after' command, e.g., `dob next: Foo bar...`.
     """
 )
 
@@ -1223,9 +1312,7 @@ ADD_FACT_NEXT = _(
 # verify_end
 ADD_FACT_TO = _(
     """
-    Stops active Fact, ending it now or at the time specified.
-
-    Stops the active Fact ending now or at the specified time.
+    Stop the active Fact, ending it now, or at the time specified.
     """
 )
 
@@ -1234,9 +1321,10 @@ ADD_FACT_TO = _(
 def ADD_FACT_UNTIL(ctx):
     _help = _(
         """
-        Aliases the 'to' command, e.g., `{rawname} until -10m: Yada...`.
-        """.strip().format(**common_format())
-    )
+        Alias for the 'to' command, e.g., `{rawname} until -10m: Yada...`.
+        """
+        .strip()
+    ).format(**common_format())
     return _help
 
 
@@ -1244,11 +1332,12 @@ def ADD_FACT_UNTIL(ctx):
 def ADD_FACT_FROM(ctx):
     _help = _(
         """
-        Inserts new Fact using the start and end time indicated.
+        Insert a new Fact using the start and end time indicated.
 
         E.g., {rawname} from 2019-01-01 00:00 to 2019-01-01 01:00: Happy New Year!
-        """.strip().format(**common_format())
-    )
+        """
+        .strip()
+    ).format(**common_format())
     return _help
 
 
@@ -1260,7 +1349,7 @@ def ADD_FACT_FROM(ctx):
 # think I should call it an "editor", and sometimes an "interactive" one.
 EDIT_FACT_HELP = _(
     """
-    Runs the interactive Fact editor in your terminal.
+    Run the interactive editor in your terminal, to add and edit Facts.
     """
 )
 
@@ -1269,11 +1358,21 @@ EDIT_FACT_HELP = _(
 # *** [EXPORT] Command help.
 # ***
 
-EXPORT_HELP = _(
-    """
-    Exports facts and other interesting data you desire.
-    """
-)
+def EXPORT_HELP(ctx):
+    _help = _(
+        """
+Export Facts to a file, for backing up to text, or grepping.
+
+{query_help}
+
+See also {codehi}{rawname} report{reset} for more robust searching
+and reporting options. The export command saves Facts to a file and
+is useful for backing up your data as a text file, or for making a
+searchable text file that you can wire into your existing notes
+management system.
+        """
+    ).format(query_help=QUERY_HELP, **common_format())
+    return _help
 
 
 # ***
@@ -1285,28 +1384,26 @@ EXPORT_HELP = _(
 # to demonstrate how all the dob-on/dob-after/etc. commands work.
 IMPORT_HELP = _(
     """
-    Imports Facts from a text file or stdin using a natural syntax.
+Import Facts from a file, or from stdin, using a natural syntax.
 
-    Useful if you cannot use dob for a while but can
-    maintain a text file. Or if you need to massage
-    data from another source into dob, it's easy to
-    prepare an import file that dob can read and use
-    to make Facts in the database.
+Useful if you cannot use dob for a while, but you can maintain a
+text file. Or if you need to massage data from another source into
+dob.
 
-    HINT: To read from stdin, you can pipe to dob:
+HINT: To read from stdin, you can pipe to dob:
 
-            echo "2020-01-09 00:00: Hi!" | dob import
+        echo "2020-01-09 00:00: Hi!" | dob import
 
-          You can use shell redirection:
+      You can use shell redirection:
 
-            dob import < path/to/my.facts
+        dob import < path/to/my.facts
 
-          Or you can use a single dash as the filename:
+      Or you can use a single dash as the filename:
 
-            dob import -
+        dob import -
 
-          For the last option, dob processes input as you type it,
-          until you press ^D.
+      For the last option, dob processes input as you type it,
+      until you press ^D.
     """
 )
 
@@ -1328,35 +1425,35 @@ COMPLETE_HELP = _(
 
 MIGRATE_GROUP_HELP = _(
     """
-    Upgrades the database after installing a new major release.
+    Upgrade the database, if necessary.
     """
 )
 
 
 MIGRATE_CONTROL_HELP = _(
     """
-    Marks a database as under version control.
+    Mark a database as under version control.
     """
 )
 
 
 MIGRATE_DOWN_HELP = _(
     """
-    Downgrades the database version by 1 script.
+    Downgrade the database version by 1 script.
     """
 )
 
 
 MIGRATE_UP_HELP = _(
     """
-    Upgrades the database version by 1 script.
+    Upgrade the database version by 1 script.
     """
 )
 
 
 MIGRATE_VERSION_HELP = _(
     """
-    Shows the database migration version.
+    Show the database migration version.
     """
 )
 
@@ -1367,7 +1464,7 @@ MIGRATE_VERSION_HELP = _(
 
 GLOBAL_OPT_VERBOSE = _(
     """
-    Be chatty. (-VV for more.)
+    Be chatty (use -VV for more).
     """
 )
 
@@ -1381,28 +1478,35 @@ GLOBAL_OPT_VERBOSER = _(
 
 GLOBAL_OPT_COLOR_NO_COLOR = _(
     """
-    Color, or plain. (Default: Auto.)
+    Color, or plain (Default: Auto).
     """
 )
 
 
 GLOBAL_OPT_PAGER_NO_PAGER = _(
     """
-    Send output to pager, or not. (Default: No.)
+    Send output to pager, or not (Default: No).
     """
 )
 
 
 GLOBAL_OPT_CONFIG = _(
     """
-    Override config setting(s) (may do multiple).
+    Override config setting(s) (multiple allowed).
     """
 )
 
 
+# MAYBE: (lb): Profiling: I tested this as a function, to avoid re.sub()
+# always being called (on every invocation, in default_config_path_abbrev),
+# but the option help is always built, so cannot escape. I wouldn't expect
+# this to really have a performance impact, though.
 GLOBAL_OPT_CONFIGFILE = _(
     """
-    Alternative path to configuration file.
+    Specify config path (Default: {default_config_path_abbrev}).
     """
+    .strip()
+).format(
+    default_config_path_abbrev=highlight_value(default_config_path_abbrev()),
 )
 
