@@ -19,8 +19,7 @@ from gettext import gettext as _
 
 from functools import update_wrapper
 
-from dob_viewer.crud.fact_dressed import FactDressed
-
+from dob_bright.crud.fact_dressed import FactDressed
 from dob_bright.termio import click_echo, dob_in_user_exit, echo_block_header
 
 from .. import __arg0name__, migrate
