@@ -17,48 +17,55 @@
 
 from gettext import gettext as _
 
-from dob_bright.termio.ascii_table import generate_table
+from dob_bright.reports.render_results import render_results
 
-from ..clickux.query_assist import error_exit_no_results, hydrate_category
+from ..clickux.query_assist import error_exit_no_results
 
 __all__ = ('list_activities', )
 
 
 def list_activities(
     controller,
-    filter_category='',
-    table_type='friendly',
-    truncate=False,
+    output_format='table',
+    table_type='texttable',
+    max_width=-1,
+    output_path=None,
+    # These two --hide flags are ignored but specified to keep out of kwargs.
+    show_usage=False,
+    show_duration=False,
     **kwargs
 ):
     """
-    List activities. Provide optional filtering by name.
+    List activity names, optionally filtered and formatted specially.
 
-    Args:
-        search_term (str): String to match ``Activity.name`` against.
-
-    Returns:
-        None: If success.
+    Writes to stdout, or to the file specified by ``output_path``.
     """
-    category = hydrate_category(controller, filter_category)
-    results = controller.activities.get_all(
-        category=category, **kwargs
-    )
+    err_context = _('activities')
 
-    if not results:
-        error_exit_no_results(_('activities'))
+    results = controller.activities.get_all(**kwargs)
+
+    results or error_exit_no_results(err_context)
 
     # This is sorta like `dob usage activity`, except we use
-    # separate columns for the activity name and category name,
-    # rather than combining as activity@category.
-    headers = (_("Activity"), _("Category"))
+    # separate columns for the Activity name and Category name,
+    # rather than combining them as Activity@Category.
+    headers = (_("Activity Name"), _("Category Name"))
     actegories = []
     for activity in results:
-        if activity.category:
+        try:
             category_name = activity.category.name
-        else:
+        except AttributeError:
             category_name = None
+
         actegories.append((activity.name, category_name))
 
-    generate_table(actegories, headers, table_type, truncate, trunccol=0)
+    render_results(
+        controller,
+        results=actegories,
+        headers=headers,
+        output_format=output_format,
+        table_type=table_type,
+        max_width=max_width,
+        output_path=output_path,
+    )
 
