@@ -17,7 +17,7 @@
 
 from gettext import gettext as _
 
-from dob_bright.termio.ascii_table import generate_table
+from dob_bright.reports.render_results import render_results
 
 from ..clickux.query_assist import error_exit_no_results
 
@@ -26,25 +26,39 @@ __all__ = ('list_categories', )
 
 def list_categories(
     controller,
-    table_type='friendly',
-    truncate=False,
+    output_format='table',
+    table_type='texttable',
+    max_width=-1,
+    output_path=None,
+    # These two --hide flags are ignored but specified to keep out of kwargs.
+    show_usage=False,
+    show_duration=False,
     **kwargs
 ):
     """
-    List all existing categories, ordered by name.
+    List category names, optionally filtered and formatted specially.
 
-    Returns:
-        None: If success.
+    Writes to stdout, or to the file specified by ``output_path``.
     """
+    err_context = _('categories')
+
     results = controller.categories.get_all(**kwargs)
 
-    if not results:
-        error_exit_no_results(_('categories'))
+    results or error_exit_no_results(err_context)
 
-    headers = (_("Name"),)
+    headers = (_("Category Name"),)
     category_names = []
     for category in results:
-        category_names.append((category.name,))
+        category_name = category.name if category else '<NULL>'
+        category_names.append((category_name,))
 
-    generate_table(category_names, headers, table_type, truncate, trunccol=0)
+    render_results(
+        controller,
+        results=category_names,
+        headers=headers,
+        output_format=output_format,
+        table_type=table_type,
+        max_width=max_width,
+        output_path=output_path,
+    )
 
