@@ -17,44 +17,47 @@
 
 from gettext import gettext as _
 
-from dob_bright.termio.ascii_table import generate_table
+from dob_bright.reports.render_results import render_results
 
-from ..clickux.query_assist import (
-    error_exit_no_results,
-    hydrate_activity,
-    hydrate_category
-)
+from ..clickux.query_assist import error_exit_no_results
 
 __all__ = ('list_tags', )
 
 
 def list_tags(
     controller,
-    filter_activity='',
-    filter_category='',
-    table_type='friendly',
-    truncate=False,
+    output_format='table',
+    table_type='texttable',
+    max_width=-1,
+    output_path=None,
+    # These two --hide flags are ignored but specified to keep out of kwargs.
+    show_usage=False,
+    show_duration=False,
     **kwargs
 ):
     """
-    List tags, with filtering and sorting options.
+    List tag names, optionally filtered and formatted specially.
 
-    Returns:
-        None: If success.
+    Writes to stdout, or to the file specified by ``output_path``.
     """
-    activity = hydrate_activity(controller, filter_activity)
-    category = hydrate_category(controller, filter_category)
-    results = controller.tags.get_all(
-        activity=activity, category=category, **kwargs
-    )
+    err_context = _('tags')
 
-    if not results:
-        error_exit_no_results(_('tags'))
+    results = controller.tags.get_all(**kwargs)
 
-    headers = (_("Name"),)
+    results or error_exit_no_results(err_context)
+
+    headers = (_("Tag Name"),)
     tag_names = []
     for tag in results:
         tag_names.append((tag.name,))
 
-    generate_table(tag_names, headers, table_type, truncate, trunccol=0)
+    render_results(
+        controller,
+        results=tag_names,
+        headers=headers,
+        output_format=output_format,
+        table_type=table_type,
+        max_width=max_width,
+        output_path=output_path,
+    )
 
