@@ -17,16 +17,21 @@
 
 from gettext import gettext as _
 
-from . import generate_usage_table
 from ..clickux.query_assist import error_exit_no_results
 
+from . import generate_usage_table
+
 __all__ = ('usage_categories', )
 
 
 def usage_categories(
     controller,
-    table_type='friendly',
-    truncate=False,
+    show_usage=False,
+    show_duration=False,
+    output_format='table',
+    table_type='texttable',
+    max_width=-1,
+    output_path=None,
     **kwargs
 ):
     """
@@ -35,10 +40,26 @@ def usage_categories(
     Returns:
         None: If success.
     """
-    results = controller.categories.get_all_by_usage(**kwargs)
+    def _usage_categories():
+        err_context = _('categories')
 
-    if not results:
-        error_exit_no_results(_('categories'))
+        results = controller.categories.get_all_by_usage(**kwargs)
 
-    generate_usage_table(results, table_type=table_type, truncate=truncate)
+        results or error_exit_no_results(err_context)
+
+        generate_usage_table(
+            controller,
+            results,
+            name_header=_("Category Name"),
+            show_usage=show_usage,
+            show_duration=show_duration,
+            output_format=output_format,
+            table_type=table_type,
+            max_width=max_width,
+            output_path=output_path,
+        )
+
+    # ***
+
+    _usage_categories()
 
