@@ -17,9 +17,9 @@
 
 """A time tracker for the command line. Utilizing the power of hamster! [nark]."""
 
-# BREADCRUMP: PROFILING
+# BREADCRUMB: PROFILING
 from nark.helpers.dev.profiling import profile_elapsed
-# BREADCRUMP: PROFILING
+# BREADCRUMB: PROFILING
 # E402 module level import not at top of file
 profile_elapsed('To dob:   _top')  # noqa: E402
 
@@ -32,31 +32,30 @@ from functools import update_wrapper
 
 import click_hotoffthehamster as click
 
-from dob_bright.termio.echoes import click_echo
-from dob_bright.termio.errors import dob_in_user_exit, dob_in_user_warning
-from dob_bright.termio.paging import flush_pager
-
-from dob_viewer.crud.fact_dressed import FactDressed
-from dob_viewer.config.styling.ignore_cmds import (
+from dob_bright.crud.fact_dressed import FactDressed
+from dob_bright.styling.ignore_cmds import (
     create_ignore_conf,
     echo_ignore_sections,
     echo_ignore_table,
     edit_ignore_file
 )
-from dob_viewer.config.styling.rules_cmds import (
+from dob_bright.styling.rules_cmds import (
     create_rules_conf,
     echo_rules_conf,
     echo_rule_names,
     echo_rules_table,
     edit_rules_conf
 )
-from dob_viewer.config.styling.styles_cmds import (
+from dob_bright.styling.styles_cmds import (
     create_styles_conf,
     echo_styles_conf,
     echo_styles_list,
     echo_styles_table,
     edit_styles_conf
 )
+from dob_bright.termio.echoes import click_echo
+from dob_bright.termio.errors import dob_in_user_exit
+from dob_bright.termio.paging import flush_pager
 
 from .clickux import help_strings
 from .clickux import help_string_add_fact
@@ -66,14 +65,13 @@ from .clickux.bunchy_help import (
     cmd_bunch_group_introducing,
     cmd_bunch_group_edit,
     cmd_bunch_group_get_meta,
-    cmd_bunch_group_datastore,
+    cmd_bunch_group_generate_report,
     cmd_bunch_group_dbms,
     cmd_bunch_group_add_fact,
     cmd_bunch_group_ongoing_fact,
     cmd_bunch_group_personalize
 )
 from .clickux.cmd_options import (
-    OptionWithDynamicHelp,
     cmd_options_edit_item,
     cmd_options_fact_add,
     cmd_options_fact_dryable,
@@ -84,20 +82,15 @@ from .clickux.cmd_options import (
     cmd_options_factoid_verify_start,
     cmd_options_factoid_verify_end,
     cmd_options_factoid_verify_both,
-    cmd_options_limit_offset,
-    cmd_options_list_activitied,
-    cmd_options_list_categoried,
-    cmd_options_list_fact,
     cmd_options_rule_name,
-    cmd_options_search,
     cmd_options_styles_internal,
-    cmd_options_styles_named,
-    cmd_options_table_renderer,
-    cmd_options_table_view,
-    cmd_options_usage,
-    postprocess_options_list_activitied,
-    postprocess_options_list_categoried,
-    postprocess_options_table_options
+    cmd_options_styles_named
+)
+from .clickux.cmd_options_search import (
+    cmd_options_any_search_query,
+    cmd_options_output_format_any_input,
+    postprocess_options_normalize_search_args,
+    postprocess_options_output_format_any_input
 )
 from .clickux.help_command import help_command_help
 from .clickux.help_detect import show_help_finally, show_help_if_no_command
@@ -125,7 +118,6 @@ from .facts.add_fact import add_fact
 from .facts.cancel_fact import cancel_fact
 from .facts.echo_fact import echo_latest_ended, echo_ongoing_fact, echo_ongoing_or_ended
 from .facts.edit_fact import edit_fact_by_pk
-from .facts.export_facts import export_facts
 from .facts.import_facts import import_facts
 from .migrate import control as migrate_control
 from .migrate import downgrade as migrate_downgrade
@@ -340,14 +332,15 @@ def config_create(ctx, controller, force):
 @config_group.command('show', aliases=['dump'], help=help_strings.CONFIG_SHOW_HELP)
 @show_help_finally
 @flush_pager
-@cmd_options_table_renderer
+@cmd_options_output_format_any_input
 @click.argument('section', nargs=1, default='')
 @click.argument('keyname', nargs=1, default='')
 @pass_controller_context
 @ensure_plugged_in
-def config_show(ctx, controller, table_type, section='', keyname=''):
+def config_show(ctx, controller, section='', keyname='', **kwargs):
     """"""
-    echo_config_table(controller, table_type, section, keyname)
+    postprocess_options_output_format_any_input(kwargs)
+    echo_config_table(controller, section, keyname, **kwargs)
 
 
 # *** [CONFIG] EDIT
@@ -405,7 +398,10 @@ def config_update(ctx, controller):
 # ***
 
 @cmd_bunch_group_personalize
-@run.group('styles', help=help_strings.STYLES_GROUP_HELP, **run_group_kwargs)
+@run.group('styles',
+           help=help_strings.STYLES_GROUP_HELP,
+           help_weight=10,
+           **run_group_kwargs)
 @show_help_finally
 @show_help_if_no_command
 @flush_pager
@@ -478,12 +474,13 @@ def styles_list(ctx, controller, internal):
 @show_help_finally
 @flush_pager
 @cmd_options_styles_named
-@cmd_options_table_renderer
+@cmd_options_output_format_any_input
 @pass_controller_context
 @ensure_plugged_in
-def styles_show(ctx, controller, name, table_type):
+def styles_show(ctx, controller, name, **kwargs):
     """"""
-    echo_styles_table(controller, name, table_type)
+    postprocess_options_output_format_any_input(kwargs)
+    echo_styles_table(controller, name, **kwargs)
 
 
 # ***
@@ -491,7 +488,10 @@ def styles_show(ctx, controller, name, table_type):
 # ***
 
 @cmd_bunch_group_personalize
-@run.group('rules', help=help_strings.RULES_GROUP_HELP, **run_group_kwargs)
+@run.group('rules',
+           help=help_strings.RULES_GROUP_HELP,
+           help_weight=20,
+           **run_group_kwargs)
 @show_help_finally
 @show_help_if_no_command
 @flush_pager
@@ -561,12 +561,13 @@ def rules_list(ctx, controller):
 @show_help_finally
 @flush_pager
 @cmd_options_rule_name
-@cmd_options_table_renderer
+@cmd_options_output_format_any_input
 @pass_controller_context
 @ensure_plugged_in
-def rules_show(ctx, controller, name, table_type):
+def rules_show(ctx, controller, name, **kwargs):
     """"""
-    echo_rules_table(controller, name, table_type)
+    postprocess_options_output_format_any_input(kwargs)
+    echo_rules_table(controller, name, **kwargs)
 
 
 # ***
@@ -574,7 +575,10 @@ def rules_show(ctx, controller, name, table_type):
 # ***
 
 @cmd_bunch_group_personalize
-@run.group('ignore', help=help_strings.IGNORE_GROUP_HELP, **run_group_kwargs)
+@run.group('ignore',
+           help=help_strings.IGNORE_GROUP_HELP,
+           help_weight=30,
+           **run_group_kwargs)
 @show_help_finally
 @show_help_if_no_command
 @flush_pager
@@ -627,12 +631,13 @@ def ignore_list(ctx, controller):
 @show_help_finally
 @flush_pager
 @cmd_options_rule_name
-@cmd_options_table_renderer
+@cmd_options_output_format_any_input
 @pass_controller_context
 @ensure_plugged_in
-def ignore_show(ctx, controller, name, table_type):
+def ignore_show(ctx, controller, name, **kwargs):
     """"""
-    echo_ignore_table(controller, name, table_type)
+    postprocess_options_output_format_any_input(kwargs)
+    echo_ignore_table(controller, name, **kwargs)
 
 
 # ***
@@ -699,8 +704,8 @@ def upgrade_legacy(ctx, controller, force, filename=None):
 # *** [STATS] Command.
 # ***
 
-@cmd_bunch_group_datastore
-@run.command('stats', help=help_strings.STATS_HELP)
+@cmd_bunch_group_dbms
+@run.command('stats', help=help_strings.STATS_HELP, help_weight=20)
 @show_help_finally
 @flush_pager
 @pass_controller_context
@@ -714,163 +719,155 @@ def nark_stats(ctx, controller):
 # *** [LIST] Commands.
 # ***
 
-@cmd_bunch_group_datastore
+@cmd_bunch_group_generate_report
 # Use a command alias to avoid conflict with builtin of same name
 # (i.e., we cannot declare this function, `def list()`).
-@run.group('list', help=help_strings.LIST_GROUP_HELP, **run_group_kwargs)
+@run.group(
+    'list', help=help_strings.LIST_GROUP_HELP, help_weight=20, **run_group_kwargs,
+)
 @show_help_finally
 @show_help_if_no_command
 @flush_pager
 @pass_controller_context
 def list_group(ctx, controller):
     """Base `list` group command run prior to any of the dob-list commands."""
+    # No-op; have already shown a help message.
     pass
 
 
 # *** ACTIVITIES.
 
-@list_group.command('activities', help=help_strings.LIST_ACTIVITIES_HELP)
+@list_group.command('activities', aliases=['activity', 'act'],
+                    help=help_strings.LIST_ACTIVITIES_HELP)
 @show_help_finally
 @flush_pager
-@cmd_options_search
-@cmd_options_list_categoried
-@cmd_options_usage
-@cmd_options_table_view
-@cmd_options_limit_offset
+@cmd_options_any_search_query(command='list', item='activity', match=True, group=False)
 @pass_controller_context
 @induct_newbies
-def list_activities(ctx, controller, *args, usage=False, **kwargs):
+def list_activities(ctx, controller, *args, **kwargs):
     """List matching activities, filtered and sorted."""
-    category = postprocess_options_list_categoried(kwargs)
-    postprocess_options_table_options(kwargs)
-    if usage:
+    query_activities(ctx, controller, *args, **kwargs)
+
+
+def query_activities(ctx, controller, *args, **kwargs):
+    postprocess_options_normalize_search_args(kwargs)
+    if kwargs['show_usage'] or kwargs['show_duration']:
         handler = usage_activity.usage_activities
     else:
         handler = list_activity.list_activities
-    handler(
-        controller,
-        *args,
-        filter_category=category,
-        **kwargs
-    )
+    handler(controller, *args, **kwargs)
 
 
 # *** CATEGORIES.
 
-@list_group.command('categories', help=help_strings.LIST_CATEGORIES_HELP)
+@list_group.command('categories', aliases=['category', 'cat'],
+                    help=help_strings.LIST_CATEGORIES_HELP)
 @show_help_finally
 @flush_pager
-@cmd_options_usage
-@cmd_options_table_view
-@cmd_options_limit_offset
+@cmd_options_any_search_query(command='list', item='category', match=True, group=False)
 @pass_controller_context
 @induct_newbies
-def list_categories(ctx, controller, *args, usage=False, **kwargs):
+def list_categories(ctx, controller, *args, **kwargs):
     """List matching categories, filtered and sorted."""
-    postprocess_options_table_options(kwargs)
-    if usage:
+    query_categories(ctx, controller, *args, **kwargs)
+
+
+def query_categories(ctx, controller, *args, **kwargs):
+    postprocess_options_normalize_search_args(kwargs)
+    if kwargs['show_usage'] or kwargs['show_duration']:
         handler = usage_category.usage_categories
     else:
         handler = list_category.list_categories
-    handler(
-        controller,
-        *args,
-        **kwargs,
-    )
+    handler(controller, *args, **kwargs)
 
 
 # *** TAGS.
 
-@list_group.command('tags', help=help_strings.LIST_TAGS_HELP)
+@list_group.command('tags', aliases=['tag'], help=help_strings.LIST_TAGS_HELP)
 @show_help_finally
 @flush_pager
-@cmd_options_search
-@cmd_options_list_activitied
-@cmd_options_list_categoried
-@cmd_options_usage
-@cmd_options_table_view
-@cmd_options_limit_offset
+# TESTME/2020-05-16: group_target seems peculiar: it's not enabled on
+# list-act or list-cat; but it could be interesting (to see what tags
+# you use on which act@gories).
+@cmd_options_any_search_query(command='list', item='tags', match=True, group=False)
 @pass_controller_context
 @induct_newbies
-def list_tags(ctx, controller, *args, usage=False, **kwargs):
+def list_tags(ctx, controller, *args, **kwargs):
     """List all tags, with filtering and sorting options."""
-    activity = postprocess_options_list_activitied(kwargs)
-    category = postprocess_options_list_categoried(kwargs)
-    postprocess_options_table_options(kwargs)
-    if usage:
+    query_tags(ctx, controller, *args, **kwargs)
+
+
+def query_tags(ctx, controller, *args, **kwargs):
+    postprocess_options_normalize_search_args(kwargs)
+    if kwargs['show_usage'] or kwargs['show_duration']:
         handler = usage_tag.usage_tags
     else:
         handler = list_tag.list_tags
-    handler(
-        controller,
-        *args,
-        filter_activity=activity,
-        filter_category=category,
-        **kwargs,
-    )
+    handler(controller, *args, **kwargs)
 
 
 # *** FACTS.
 
-def _list_facts(controller, *args, usage=False, **kwargs):
-    """List matching facts, filtered and sorted."""
-    """Fetch facts matching certain criteria."""
-    activity = postprocess_options_list_activitied(kwargs)
-    category = postprocess_options_list_categoried(kwargs)
-    postprocess_options_table_options(kwargs)
-    # FIXME: (lb): Should probably impose limit by default
-    #          (without, my terminal hangs for a long while).
-    list_fact.list_facts(
-        controller,
-        *args,
-        include_usage=usage,
-        filter_activity=activity,
-        filter_category=category,
-        **kwargs,
-    )
+def _list_facts(controller, *args, cmd_journal=False, **kwargs):
+    """Find matching facts, filtered and sorted."""
+    postprocess_options_normalize_search_args(kwargs, cmd_journal=cmd_journal)
+    list_fact.list_facts(controller, *args, **kwargs)
 
 
-def generate_list_facts_command(func):
-    @cmd_options_search
-    @cmd_options_list_activitied
-    @cmd_options_list_categoried
-    @cmd_options_usage
-    @cmd_options_table_view
-    @cmd_options_limit_offset
-    @cmd_options_list_fact
-    @pass_controller_context
-    @induct_newbies
-    def dob_list_facts(ctx, controller, *args, doc, **kwargs):
-        _list_facts(controller, *args, block_format=doc, **kwargs)
-    return update_wrapper(dob_list_facts, func)
-
-
-@list_group.command('facts', help=help_strings.LIST_FACTS_HELP)
+@list_group.command('facts', aliases=['fact'], help=help_strings.LIST_FACTS_HELP)
 @show_help_finally
 @flush_pager
-@generate_list_facts_command
-def dob_list_facts(controller, *args, **kwargs):
-    assert(False)  # Not reachable, because generate_list_facts_command.
-    pass
+# The `dob find` and `dob list fact` commands are the same.
+@cmd_options_any_search_query(command='list', item='fact', match=True, group=True)
+@pass_controller_context
+@induct_newbies
+def dob_list_facts(ctx, controller, *args, **kwargs):
+    _list_facts(controller, *args, **kwargs)
 
 
-@cmd_bunch_group_datastore
-# MAYBE: Should we alias the command at dob-search?
-@run.command('search', help=help_strings.SEARCH_HELP)
+# ***
+# *** [SEARCH] Facts Command.
+# ***
+
+@cmd_bunch_group_generate_report
+@run.command('find', aliases=['search'], help=help_strings.SEARCH_HELP, help_weight=5)
 @show_help_finally
 @flush_pager
-@generate_list_facts_command
-def search_facts(controller, *args, **kwargs):
-    assert(False)  # Not reachable, because generate_list_facts_command.
-    pass
+# The `dob find` and `dob list fact` commands are the same.
+@cmd_options_any_search_query(command='list', item='fact', match=True, group=True)
+@pass_controller_context
+@induct_newbies
+def search_facts(ctx, controller, *args, **kwargs):
+    _list_facts(controller, *args, **kwargs)
+
+
+# ***
+# *** [REPORT] Facts Command.
+# ***
+
+@cmd_bunch_group_generate_report
+@run.command('report', help=help_strings.REPORT_HELP, help_weight=10)
+@show_help_finally
+@flush_pager
+# The `dob report` command is `dob find` with specific defaults.
+@cmd_options_any_search_query(command='journal', item='fact', match=True, group=True)
+@pass_controller_context
+@induct_newbies
+def journal_report(ctx, controller, *args, **kwargs):
+    # The journal command groups by Activity, Category, and Day by default,
+    # unless the user specified a different grouping. Note that to apply no
+    # grouping, the user would have to use the `dob find` command instead.
+    _list_facts(controller, *args, cmd_journal=True, **kwargs)
 
 
 # ***
 # *** [USAGE] Commands.
 # ***
 
-@cmd_bunch_group_datastore
-@run.group('usage', help=help_strings.USAGE_GROUP_HELP, **run_group_kwargs)
+@cmd_bunch_group_generate_report
+@run.group(
+    'usage', help=help_strings.USAGE_GROUP_HELP, help_weight=15, **run_group_kwargs,
+)
 @show_help_finally
 @show_help_if_no_command
 @flush_pager
@@ -882,96 +879,59 @@ def usage_group(ctx, controller):
 
 # *** ACTIVITIES.
 
-@usage_group.command('activities', help=help_strings.USAGE_ACTIVITIES_HELP)
+@usage_group.command('activities', aliases=['activity', 'act'],
+                     help=help_strings.USAGE_ACTIVITIES_HELP)
 @show_help_finally
 @flush_pager
-@cmd_options_search
-@cmd_options_list_categoried
-@cmd_options_table_view
-@cmd_options_limit_offset
+@cmd_options_any_search_query(command='usage', item='activity', match=True, group=False)
 @pass_controller_context
 @induct_newbies
 def usage_activities(ctx, controller, *args, **kwargs):
     """List all activities. Provide optional filtering by name."""
-    category = postprocess_options_list_categoried(kwargs)
-    postprocess_options_table_options(kwargs)
-    usage_activity.usage_activities(
-        controller,
-        *args,
-        filter_category=category,
-        **kwargs
-    )
+    query_activities(ctx, controller, *args, **kwargs)
 
 
 # *** CATEGORIES.
 
-@usage_group.command('categories', help=help_strings.USAGE_CATEGORIES_HELP)
+@usage_group.command('categories', aliases=['category', 'cat'],
+                     help=help_strings.USAGE_CATEGORIES_HELP)
 @show_help_finally
 @flush_pager
-@cmd_options_search
-@cmd_options_table_view
-@cmd_options_limit_offset
+@cmd_options_any_search_query(command='usage', item='category', match=True, group=False)
 @pass_controller_context
 @induct_newbies
 def usage_categories(ctx, controller, *args, **kwargs):
     """List all categories. Provide optional filtering by name."""
-    postprocess_options_table_options(kwargs)
-    usage_category.usage_categories(
-        controller,
-        *args,
-        **kwargs
-    )
+    query_categories(ctx, controller, *args, **kwargs)
 
 
 # *** TAGS.
 
-@usage_group.command('tags', help=help_strings.USAGE_TAGS_HELP)
+@usage_group.command('tags', aliases=['tag'], help=help_strings.USAGE_TAGS_HELP)
 @show_help_finally
 @flush_pager
-@cmd_options_search
-@cmd_options_list_activitied
-@cmd_options_list_categoried
-@cmd_options_table_view
-@cmd_options_limit_offset
+@cmd_options_any_search_query(command='usage', item='tags', match=True, group=False)
 @pass_controller_context
 @induct_newbies
 def usage_tags(ctx, controller, *args, **kwargs):
     """List all tags' usage counts, with filtering and sorting options."""
-    activity = postprocess_options_list_activitied(kwargs)
-    category = postprocess_options_list_categoried(kwargs)
-    postprocess_options_table_options(kwargs)
-    usage_tag.usage_tags(
-        controller,
-        *args,
-        filter_activity=activity,
-        filter_category=category,
-        **kwargs,
-    )
+    query_tags(ctx, controller, *args, **kwargs)
 
 
 # *** FACTS.
 
-@usage_group.command('facts', help=help_strings.USAGE_FACTS_HELP)
+@usage_group.command('facts', aliases=['fact'], help=help_strings.USAGE_FACTS_HELP)
 @show_help_finally
 @flush_pager
-@cmd_options_search
-@cmd_options_list_activitied
-@cmd_options_list_categoried
-@cmd_options_table_view
-@cmd_options_limit_offset
+@cmd_options_any_search_query(command='usage', item='fact', match=True, group=True)
 @pass_controller_context
 @induct_newbies
 def usage_facts(ctx, controller, *args, **kwargs):
     """List all tags' usage counts, with filtering and sorting options."""
-    activity = postprocess_options_list_activitied(kwargs)
-    category = postprocess_options_list_categoried(kwargs)
-    postprocess_options_table_options(kwargs)
+    postprocess_options_normalize_search_args(kwargs)
     list_fact.list_facts(
         controller,
         *args,
-        include_usage=True,
-        filter_activity=activity,
-        filter_category=category,
         **kwargs,
     )
 
@@ -1056,8 +1016,8 @@ def generate_add_fact_command(time_hint):
 @generate_add_fact_command("verify_none")
 def add_fact_now(controller, *args, **kwargs):
     """Start or add a fact using the `now` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 @cmd_bunch_group_add_fact
@@ -1069,8 +1029,8 @@ def add_fact_now(controller, *args, **kwargs):
 @generate_add_fact_command("verify_none")
 def add_fact_on(controller, *args, **kwargs):
     """Start or add a fact using the `on` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 @cmd_bunch_group_add_fact
@@ -1081,8 +1041,8 @@ def add_fact_on(controller, *args, **kwargs):
 @generate_add_fact_command("verify_start")
 def add_fact_at(controller, *args, **kwargs):
     """Start or add a fact using the `at` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 @cmd_bunch_group_add_fact
@@ -1093,8 +1053,8 @@ def add_fact_at(controller, *args, **kwargs):
 @generate_add_fact_command("verify_both")
 def add_fact_from(controller, *args, **kwargs):
     """Add a fact using the `from ... to/until` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 @cmd_bunch_group_add_fact
@@ -1105,8 +1065,8 @@ def add_fact_from(controller, *args, **kwargs):
 @generate_add_fact_command("verify_end")
 def add_fact_to(controller, *args, **kwargs):
     """Start or add a fact using the `to` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 @cmd_bunch_group_add_fact
@@ -1118,8 +1078,8 @@ def add_fact_to(controller, *args, **kwargs):
 @generate_add_fact_command("verify_end")
 def add_fact_until(controller, *args, **kwargs):
     """Start or add a fact using the `until` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 @cmd_bunch_group_add_fact
@@ -1131,8 +1091,8 @@ def add_fact_until(controller, *args, **kwargs):
 @generate_add_fact_command("verify_then")
 def add_fact_then(controller, *args, **kwargs):
     """Start or add a fact using the `then` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 @cmd_bunch_group_add_fact
@@ -1144,8 +1104,8 @@ def add_fact_then(controller, *args, **kwargs):
 @generate_add_fact_command("verify_still")
 def add_fact_still(controller, *args, **kwargs):
     """Start or add a fact using the `still` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 @cmd_bunch_group_add_fact
@@ -1157,8 +1117,8 @@ def add_fact_still(controller, *args, **kwargs):
 @generate_add_fact_command("verify_after")
 def add_fact_after(controller, *args, **kwargs):
     """Start or add a fact using the `after` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 @cmd_bunch_group_add_fact
@@ -1172,8 +1132,8 @@ def add_fact_after(controller, *args, **kwargs):
 @generate_add_fact_command("verify_after")
 def add_fact_next(controller, *args, **kwargs):
     """Start or add a fact using the `next` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 # ***
@@ -1183,20 +1143,20 @@ def add_fact_next(controller, *args, **kwargs):
 
 # NOPE: @cmd_bunch_group_add_fact
 @cmd_bunch_group_ongoing_fact
-@run.command('start', help=help_strings.ADD_FACT_START)
+@run.command('start', help=help_strings.ADD_FACT_START, help_weight=5)
 @show_help_finally
 @flush_pager
 @cmd_options_factoid_verify_none
 @generate_add_fact_command('verify_none')
 def add_fact_start(controller, *args, **kwargs):
     """Start or add a fact using the `now` directive."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 # NOPE: @cmd_bunch_group_add_fact
 @cmd_bunch_group_ongoing_fact
-@run.command('stop', help=help_strings.STOP_HELP)
+@run.command('stop', help=help_strings.STOP_HELP, help_weight=5)
 @show_help_finally
 @flush_pager
 @cmd_options_factoid_verify_end
@@ -1207,8 +1167,8 @@ def add_fact_start(controller, *args, **kwargs):
 @generate_add_fact_command('verify_end')
 def stop(controller, *args, **kwargs):
     """Complete the active fact (by setting its 'end')."""
-    assert(False)  # Not reachable, because generate_add_fact_command.
-    pass
+    # Not reachable, because generate_add_fact_command.
+    assert False  # pragma: no cover
 
 
 # ***
@@ -1346,79 +1306,18 @@ def edit_fact_by_key(
 # *** [EXPORT] Command.
 # ***
 
-CMD_EXPORT_OPT_FORMAT_CHOICES = ['csv', 'tsv', 'xml', 'ical']
-
-
-CMD_EXPORT_OPT_FORMAT_DEFAULT = 'csv'
-
-
-def cmd_export_opt_output_default(controller):
-    if controller is not None:
-        return '{}.{{format}}'.format(controller.config['term.export_path'])
-    else:
-        return _('(Dynamic)')
-
-
 @cmd_bunch_group_dbms
 @run.command('export', help=help_strings.EXPORT_HELP)
 @show_help_finally
 @flush_pager
-@click.option(
-    '-o', '--output',
-    cls=OptionWithDynamicHelp,
-    help=_('Path to export file.'),
-    default=cmd_export_opt_output_default,
-    show_default=True,
-)
-@click.option(
-    '-f', '--format',
-    type=click.Choice(CMD_EXPORT_OPT_FORMAT_CHOICES),
-    help=_('Output format.'),
-    default=CMD_EXPORT_OPT_FORMAT_DEFAULT,
-    show_default=True,
-)
-@click.option('--csv', is_flag=True, help=_('Alias for `--format csv`'))
-@click.option('--tsv', is_flag=True, help=_('Alias for `--format tsv`'))
-@click.option('--xml', is_flag=True, help=_('Alias for `--format xml`'))
-@click.option('--ical', is_flag=True, help=_('Alias for `--format ical`'))
-@cmd_options_search
-@cmd_options_limit_offset
-@cmd_options_list_activitied
-@cmd_options_list_categoried
+@cmd_options_any_search_query(command='export', item='fact', match=True, group=False)
 @pass_controller_context
 @induct_newbies
-def transcode_export(ctx, controller, *args, output, format, **kwargs):
-    """Export all facts of within a given timewindow to a file of specified format."""
-    def _transcode_export():
-        activity = postprocess_options_list_activitied(kwargs)
-        category = postprocess_options_list_categoried(kwargs)
-        export_facts(
-            controller,
-            *args,
-            to_format=consolidate_format_options(),
-            file_out=output,
-            filter_activity=activity,
-            filter_category=category,
-            **kwargs
-        )
-
-    def consolidate_format_options():
-        chosen_fmt = format
-        fmts_specified = []
-        if chosen_fmt != CMD_EXPORT_OPT_FORMAT_DEFAULT:
-            fmts_specified = [chosen_fmt, ]
-        for switch in CMD_EXPORT_OPT_FORMAT_CHOICES:
-            if kwargs[switch]:
-                chosen_fmt = switch
-                fmts_specified.append(switch)
-            del kwargs[switch]
-        if len(fmts_specified) > 1:
-            dob_in_user_warning(_(
-                'More than one format specified: {}'
-            ).format(fmts_specified))
-        return chosen_fmt
-
-    _transcode_export()
+def transcode_export(ctx, controller, *args, **kwargs):
+    """Export all facts of within a given time window to a file of specified format."""
+    postprocess_options_normalize_search_args(kwargs)
+    kwargs['output_format'] = 'factoid'
+    list_fact.list_facts(controller, *args, **kwargs)
 
 
 # ***
@@ -1438,7 +1337,7 @@ def transcode_export(ctx, controller, *args, output, format, **kwargs):
               help=_('With --output, split facts with a horizontal rule'))
 @click.option('--backup/--no-backup', '-B', default=True, show_default=True,
               help=_('Keep plaintext backup of edited facts until committed'))
-@click.option('-X', '--leave-backup', is_flag=True,
+@click.option('-b', '--leave-backup', is_flag=True,
               help=_('Leave working backup file after commit'))
 @cmd_options_fact_dryable
 @cmd_options_fact_import
@@ -1538,7 +1437,15 @@ def complete(ctx, controller):
 # ***
 
 @cmd_bunch_group_dbms
-@run.group('migrate', help=help_strings.MIGRATE_GROUP_HELP, **run_group_kwargs)
+@run.group(
+    'migrate',
+    help=help_strings.MIGRATE_GROUP_HELP,
+    # (lb): Hidden until needed. Does db really need to evolve?
+    # Then again, I don't want to be rigid like JSON or Md specs.
+    # I'm open to fresh ideas.
+    hidden=True,
+    **run_group_kwargs,
+)
 @show_help_finally
 @show_help_if_no_command
 @flush_pager
