@@ -19,11 +19,11 @@ import random
 
 from gettext import gettext as _
 
+from dob_bright.crud.fact_from_factoid import must_create_fact_from_factoid
+from dob_bright.crud.fix_times import mend_fact_timey_wimey
 from dob_bright.termio import dob_in_user_exit
 
-from dob_viewer.crud.fact_from_factoid import must_create_fact_from_factoid
-from dob_viewer.crud.fix_times import mend_fact_timey_wimey
-from dob_viewer.crud.interrogate import ask_user_for_edits
+from dob_prompt.prompters.triple_prompter import ask_user_for_edits
 
 from .save_backedup import prompt_and_save_backedup
 
