@@ -22,6 +22,7 @@ from gettext import gettext as _
 import click_hotoffthehamster as click
 from inflector import English, Inflector
 
+from dob_bright.crud.fix_times import mend_fact_timey_wimey
 from dob_bright.termio import (
     attr,
     click_echo,
@@ -29,8 +30,6 @@ from dob_bright.termio import (
     fg,
 )
 
-from dob_viewer.crud.fix_times import mend_fact_timey_wimey
-
 from .echo_fact import echo_fact
 
 __all__ = (
@@ -227,11 +226,7 @@ def echo_ongoing_completed(controller, fact, cancelled=False):
                 localize=True,
 
                 colorful=colorful,
-
-                # FIXME/2018-06-12: (lb): Too wide (wraps to next line);
-                # doesn't account for leading fact parts (times, act@gory, tags).
-                cut_width=cut_width,
-
+                cut_width_complete=cut_width,
                 show_elapsed=True,
             )
         )
